@@ -13,6 +13,7 @@ class Function(Proxy):
         self.required_params = None
         self.optional_params = None
         self._decorate_or_call = self._decorate
+        self._method_cache = {}
         if len(args) == 1 and callable(args[0]) and len(kw) == 0:
             self._init()
             self._decorate(args[0])
@@ -23,7 +24,18 @@ class Function(Proxy):
         return self._decorate_or_call(*args, **kw)
     
     def __get__(self, obj, cls):
-        return Method(self, obj, cls)
+        if obj is None:
+            cached = self._method_cache.get(cls)
+            if cached is not None:
+                return cached
+        call_args = (obj,) if obj is not None else ()
+        method = partial(Function, call_args=call_args)(self)
+        method.im_class = cls
+        method.im_func = method.__func__ = self
+        method.im_self = method.__self__ = obj
+        if obj is None:
+            self._method_cache[cls] = method
+        return method
     
     def __str__(self):
         return '<Function %s.%s>' % (self._func.__module__, self.__name__)
@@ -87,7 +99,7 @@ class Function(Proxy):
     def _target(self):
         return self._func
     
-def PartialFunction(func, init_args=(), init_kw=None, call_args=(), call_kw=None):
+def partial(func, init_args=(), init_kw=None, call_args=(), call_kw=None):
     if init_kw is None:
         init_kw = {}
     if call_kw is None:
@@ -113,14 +125,6 @@ def PartialFunction(func, init_args=(), init_kw=None, call_args=(), call_kw=None
             self.optional_params = tuple([(k, v) for (k, v) in self.optional_params if k not in call_kw])
     return _PartialFunction
         
-def Method(func, obj, cls):
-    call_args = (obj,) if obj is not None else ()
-    method = PartialFunction(Function, call_args=call_args)(func)
-    method.im_class = cls
-    method.im_func = method.__func__ = func
-    method.im_self = method.__self__ = obj
-    return method
-
 def _is_bound_method(func):
     '''
     >>> def foo():
